@@ -22,7 +22,7 @@ BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 DEFAULT_BASE_URL = "https://arkindex.teklia.com/"
 
 # Endpoint accessed by the client on instantiation to retrieve the OpenAPI schema
-SCHEMA_ENDPOINT = "/api/v1/openapi/?format=openapi-json"
+SCHEMA_ENDPOINT = "/api/v1/openapi/?format=json"
 
 logger = logging.getLogger(__name__)
 
@@ -116,6 +116,10 @@ class ArkindexClient(apistar.Client):
             operation = _find_operation(schema, link_info.link.name)
             link_info.link.deprecated = operation.get("deprecated", False)
 
+            # Detect paginated links
+            if "x-paginated" in operation:
+                link_info.link._paginated = operation["x-paginated"]
+
             # Remove domains from each endpoint; allows APIStar to properly handle our base URL
             # https://github.com/encode/apistar/issues/657
             original_url = urlsplit(link_info.link.url)
@@ -176,14 +180,18 @@ class ArkindexClient(apistar.Client):
         # Add the Referer header to allow Django CSRF to function
         self.transport.headers.setdefault("Referer", self.document.url)
 
-    def paginate(self, *args, **kwargs):
+    def paginate(self, operation_id, *args, **kwargs):
         """
         Perform a usual request as done by APIStar, but handle paginated endpoints.
 
         :return: An iterator for a paginated endpoint.
-        :rtype: arkindex.pagination.ResponsePaginator
+        :rtype: Union[arkindex.pagination.ResponsePaginator, dict, list]
         """
-        return ResponsePaginator(self, *args, **kwargs)
+        link = self.lookup_operation(operation_id)
+        # If there was no x-paginated, trust the caller and assume the endpoint is paginated
+        if getattr(link, "_paginated", True):
+            return ResponsePaginator(self, operation_id, *args, **kwargs)
+        return self.request(operation_id, *args, **kwargs)
 
     def login(self, email, password):
         """
